@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2012-2017 Richard Hughes <richard@hughsie.com>
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
@@ -53,11 +53,11 @@ GType		 gs_plugin_query_type			(void);
  * Called when an #GsApp has not been claimed (i.e. a management plugin has not
  * been set).
  *
- * A claimed application means other plugins will not try to perform actions
- * such as install, remove or update. Most applications are claimed when they
+ * A claimed app means other plugins will not try to perform actions
+ * such as install, remove or update. Most apps are claimed when they
  * are created.
  *
- * If a plugin can adopt this application then it should call
+ * If a plugin can adopt this app then it should call
  * gs_app_set_management_plugin() on @app.
  **/
 void		 gs_plugin_adopt_app			(GsPlugin	*plugin,
@@ -72,8 +72,8 @@ void		 gs_plugin_adopt_app			(GsPlugin	*plugin,
  *
  * Get the list of updates.
  *
- * NOTE: Actually downloading the updates can be done in gs_plugin_download_app()
- * or in gs_plugin_download().
+ * NOTE: Actually downloading the updates can be done in
+ * #GsPlugin.update_apps_async().
  *
  * Plugins are expected to add new apps using gs_app_list_add().
  *
@@ -130,7 +130,7 @@ gboolean	 gs_plugin_add_updates_historical	(GsPlugin	*plugin,
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
- * Launch the specified application using a plugin-specific method.
+ * Launch the specified app using a plugin-specific method.
  * This is normally setting some environment or launching a specific binary.
  *
  * Plugins can simply use gs_plugin_app_launch() if no plugin-specific
@@ -166,7 +166,7 @@ gboolean	 gs_plugin_update_cancel		(GsPlugin	*plugin,
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
- * Install the application.
+ * Install the app.
  *
  * Plugins are expected to send progress notifications to the UI using
  * gs_app_set_progress() using the passed in @app.
@@ -195,7 +195,7 @@ gboolean	 gs_plugin_app_install			(GsPlugin	*plugin,
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
- * Remove the application.
+ * Remove the app.
  *
  * Plugins are expected to send progress notifications to the UI using
  * gs_app_set_progress() using the passed in @app.
@@ -217,94 +217,6 @@ gboolean	 gs_plugin_app_remove			(GsPlugin	*plugin,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
-/**
- * gs_plugin_update_app:
- * @plugin: a #GsPlugin
- * @app: a #GsApp
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Update the application live.
- *
- * Plugins are expected to send progress notifications to the UI using
- * gs_app_set_progress() using the passed in @app.
- *
- * All functions can block, but should sent progress notifications, e.g. using
- * gs_app_set_progress() if they will take more than tens of milliseconds
- * to complete.
- *
- * On failure the error message returned will usually only be shown on the
- * console, but they can also be retrieved using gs_plugin_loader_get_events().
- *
- * NOTE: Once the action is complete, the plugin must set the new state of @app
- * to %GS_APP_STATE_INSTALLED or %GS_APP_STATE_UNKNOWN if not known.
- *
- * If %GS_APP_QUIRK_IS_PROXY is set on the application then the actual #GsApp
- * set in @app will be the related application of the parent. Plugins do not
- * need to manually iterate on the related list of applications.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_update_app			(GsPlugin	*plugin,
-							 GsApp		*app,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
-/**
- * gs_plugin_download_app:
- * @plugin: a #GsPlugin
- * @app: a #GsApp
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Downloads the application and any dependencies ready to be installed or
- * updated.
- *
- * Plugins are expected to schedule downloads using the system download
- * scheduler if appropriate (if the download is not guaranteed to be under a few
- * hundred kilobytes, for example), so that the user’s metered data preferences
- * are honoured.
- *
- * Plugins are expected to send progress notifications to the UI using
- * gs_app_set_progress() using the passed in @app.
- *
- * All functions can block, but should sent progress notifications, e.g. using
- * gs_app_set_progress() if they will take more than tens of milliseconds
- * to complete.
- *
- * If the @app is already downloaded, do not return an error and return %TRUE.
- *
- * On failure the error message returned will usually only be shown on the
- * console, but they can also be retrieved using gs_plugin_loader_get_events().
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_download_app			(GsPlugin	*plugin,
-							 GsApp		*app,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
-/**
- * gs_plugin_download:
- * @plugin: a #GsPlugin
- * @apps: a #GsAppList
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Downloads a list of applications ready to be installed or updated.
- *
- * Plugins are expected to schedule downloads using the system download
- * scheduler if appropriate (if the download is not guaranteed to be under a few
- * hundred kilobytes, for example), so that the user’s metered data preferences
- * are honoured.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_download			(GsPlugin	*plugin,
-							 GsAppList	*apps,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
 /**
  * gs_plugin_app_upgrade_download:
  * @plugin: a #GsPlugin
@@ -353,7 +265,7 @@ gboolean	 gs_plugin_app_upgrade_trigger		(GsPlugin	*plugin,
  * match the mimetype of @file and that a single #GsApp will be in the returned
  * list. If no plugins can handle the file, the list will be empty.
  *
- * For example, the PackageKit plugin can turn a .rpm file into a application
+ * For example, the PackageKit plugin can turn a .rpm file into a app
  * of kind %AS_COMPONENT_KIND_UNKNOWN but that in some cases it will be further refined
  * into a %AS_COMPONENT_KIND_DESKTOP_APP (with all the extra metadata) by the appstream
  * plugin.
@@ -392,22 +304,6 @@ gboolean	 gs_plugin_url_to_app			(GsPlugin	*plugin,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
-/**
- * gs_plugin_update:
- * @plugin: a #GsPlugin
- * @apps: a #GsAppList
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Updates a list of applications, typically scheduling them for offline update.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_update			(GsPlugin	*plugin,
-							 GsAppList	*apps,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
 /**
  * gs_plugin_add_langpacks:
  * @plugin: a #GsPlugin
