@@ -240,9 +240,10 @@ set_updates_description_ui (GsAppDetailsPage *page, GsApp *app)
 
 	/* set update header */
 	set_update_description (page, TRUE);
-	escaped_summary = g_markup_escape_text (gs_app_get_summary (app), -1);
+	if (gs_app_get_summary (app) != NULL)
+		escaped_summary = g_markup_escape_text (gs_app_get_summary (app), -1);
 	adw_status_page_set_title (ADW_STATUS_PAGE (page->status_page), gs_app_get_name (app));
-	adw_status_page_set_description (ADW_STATUS_PAGE (page->status_page), escaped_summary);
+	adw_status_page_set_description (ADW_STATUS_PAGE (page->status_page), escaped_summary != NULL ? escaped_summary : "");
 
 	/* set the icon; fall back to 64px if 96px isn’t available, which sometimes
 	 * happens at 2× scale factor (hi-DPI) */
@@ -263,7 +264,7 @@ set_updates_description_ui (GsAppDetailsPage *page, GsApp *app)
 		icon = gs_app_get_icon_for_size (app,
 						 icon_size,
 						 gtk_widget_get_scale_factor (GTK_WIDGET (page)),
-						 "system-component-application");
+						 "application-x-executable");
 	}
 
 	display = gdk_display_get_default ();
