@@ -3,12 +3,12 @@
  *
  * Copyright (C) 2021 Purism SPC
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
-#include <gtk/gtk.h>
+#include <adwaita.h>
 
 #include "gnome-software-private.h"
 
@@ -16,14 +16,12 @@ G_BEGIN_DECLS
 
 #define GS_TYPE_APP_DETAILS_PAGE (gs_app_details_page_get_type ())
 
-G_DECLARE_FINAL_TYPE (GsAppDetailsPage, gs_app_details_page, GS, APP_DETAILS_PAGE, GtkBox)
+G_DECLARE_FINAL_TYPE (GsAppDetailsPage, gs_app_details_page, GS, APP_DETAILS_PAGE, AdwNavigationPage)
 
-GtkWidget	*gs_app_details_page_new			(void);
+GtkWidget	*gs_app_details_page_new			(GsPluginLoader		*plugin_loader);
+GsPluginLoader	*gs_app_details_page_get_plugin_loader		(GsAppDetailsPage	*page);
 GsApp		*gs_app_details_page_get_app			(GsAppDetailsPage	*page);
 void		 gs_app_details_page_set_app			(GsAppDetailsPage	*page,
 								 GsApp			*app);
-gboolean	 gs_app_details_page_get_show_back_button	(GsAppDetailsPage	*page);
-void		 gs_app_details_page_set_show_back_button	(GsAppDetailsPage	*page,
-								 gboolean		 show_back_button);
 
 G_END_DECLS
